# Werkudara Changelog

## v1.2.0 - September 30, 2024

- New: Added changelog, about, license, and help action windows
- Improved: Updated changelog details and app guide
- Fix: Added missing dependency: `openpyxl`

## v1.1.0 - August 30, 2024

- Fix: Fixed error cannot import `ui_exported` from the module

## v1.0.0 - August 30, 2024

- Info: Initial commit and release of the Werkudara app
- New: Added local author/lecturer database refresher, exporter, importer, and purger
- New: Added automatic synchronization feature
- New: Added lecturer basic information display
- New: Added settings to locally save Bima administrator credential locally
